var _EVENT_INFO;

import analytics from './index';
/**
 * TCF Api Version to use
 * @type {number}
 */

var TCF_API_VERSION = 2;
/**
 * List of purpose ids needed to be able to track with all info
 * @type {Array<number>}
 */

var NEEDED_PURPOSES = [8, 10];
/**
 * Event that determines that the user has performed an action
 * @type {string}
 */

var TCF_EVENT_USER_ACTION_COMPLETE = 'useractioncomplete';
/**
 * Event that determines that the user is seeing the UI to give consent
 * @type {string}
 */

var TCF_EVENT_SHOW_UI = 'cmpuishown';
/**
 * Check if we're on client and tcfApi is available on window object
 * @returns {Boolean}
 */

var checkTcfIsAvailable = function checkTcfIsAvailable() {
  var isAvailable = typeof window !== 'undefined' && !!window.__tcfapi;
  !isAvailable && console.warn('[tcfTracking] window.__tcfapi is not available');
  return isAvailable;
};
/**
 * Check from a list of consents if user has accepted being tracked
 * @param {{[purposeId: string]: boolean}} userConsents
 * @returns {Boolean}
 */


var checkHasUserConsentedTracking = function checkHasUserConsentedTracking(userConsents) {
  return NEEDED_PURPOSES.every(function (purposeId) {
    return userConsents["" + purposeId];
  });
};
/**
 * State of user according to GDPR regarding tracking
 */


var USER_GDPR = {
  ACCEPTED: 'ACCEPTED',
  DECLINED: 'DECLINED',
  UNKNOWN: 'UNKNOWN'
};
/**
 * Events info according
 * @type {{ [event: string]: [gdprValue: string, eventId: string]}}
 */

var EVENT_INFO = (_EVENT_INFO = {}, _EVENT_INFO[USER_GDPR.ACCEPTED] = ['Privacy Accepted', 'accepted'], _EVENT_INFO[USER_GDPR.DECLINED] = ['Privacy Declined', 'declined'], _EVENT_INFO[USER_GDPR.UNKNOWN] = ['Privacy Impression', 'declined'], _EVENT_INFO);
/**
 * Track a specific TCF event
 * @param {object} params
 * @param {string} params.eventId
 * @param {string} params.gdprValue
 * @return {Promise}
 */

var trackTcf = function trackTcf(_ref) {
  var eventId = _ref.eventId,
      gdprValue = _ref.gdprValue;
  return analytics.track('Event Fired', {
    channel: 'GDPR',
    event_id: eventId,
    gdpr_privacy: gdprValue
  });
};
/**
 * Init TCF Tracking User Consents with Segment
 */


export default function initTcfTracking() {
  checkTcfIsAvailable() && window.__tcfapi('addEventListener', TCF_API_VERSION, function (_ref2, success) {
    var eventStatus = _ref2.eventStatus,
        purpose = _ref2.purpose;
    if (!success) return Promise.resolve();

    if (eventStatus === TCF_EVENT_SHOW_UI) {
      var _EVENT_INFO$UNKNOWN = EVENT_INFO.UNKNOWN,
          eventId = _EVENT_INFO$UNKNOWN[0],
          gdprValue = _EVENT_INFO$UNKNOWN[1];
      return trackTcf({
        eventId: eventId,
        gdprValue: gdprValue
      });
    }

    if (eventStatus === TCF_EVENT_USER_ACTION_COMPLETE) {
      var consents = purpose.consents;
      var hasConsents = checkHasUserConsentedTracking(consents);
      var userGdprState = hasConsents ? USER_GDPR.ACCEPTED : USER_GDPR.DECLINED;
      var _EVENT_INFO$userGdprS = EVENT_INFO[userGdprState],
          _eventId = _EVENT_INFO$userGdprS[0],
          _gdprValue = _EVENT_INFO$userGdprS[1];
      return trackTcf({
        eventId: _eventId,
        gdprValue: _gdprValue
      });
    }
  });
}